@@ -12,8 +12,8 @@ from selenium.webdriver.support.ui import Select
 from selenium.common.exceptions import NoSuchElementException        
 from selenium.common.exceptions import StaleElementReferenceException
 from selenium.webdriver.common.action_chains import ActionChains
-
 from selenium.webdriver.remote.remote_connection import LOGGER
+from selenium.webdriver.common.desired_capabilities import DesiredCapabilities
 
 import logging
 import platform
@@ -53,11 +53,12 @@ class Selenium(Scraper):
         options.add_argument("user-agent=Mozilla/5.0 (Windows NT 10.0; Win64; x64) AppleWebKit/537.36 (KHTML, like Gecko) Chrome/74.0.3729.169 Safari/537.36") # new
         # options.add_argument("user-data-dir=C:\\Users\\LCADM.G.Gargiuolo\\AppData\\Local\\Google\\Chrome\\User Data\\Default") # new
 
+        self.driver = webdriver.Remote('http://selenium:4444/wd/hub', desired_capabilities=DesiredCapabilities.CHROME)
 
-        if platform.system() == 'Windows':
-            self.driver = webdriver.Chrome(executable_path='c:\chromedriver.exe', options=options)
-        if platform.system() == 'Linux':
-            self.driver = webdriver.Chrome(executable_path='/chromedriver', options=options)
+        # if platform.system() == 'Windows':
+        #     self.driver = webdriver.Chrome(executable_path='c:\chromedriver.exe', options=options)
+        # elif platform.system() == 'Linux':
+        #     self.driver = webdriver.Chrome(executable_path='/chromedriver', options=options)
 
         if len(window_size) > 0:
             self.driver.set_window_position(x=0, y=0)
